library(tidyverse)


# casos -------------------------------------------------------------------

casos <- read_csv(
  "datos/positivos_covid-utf8.csv",
  col_types = cols(
      UUID = col_character(),
      DEPARTAMENTO = col_character(),
      PROVINCIA = col_character(),
      DISTRITO = col_character(),
      METODODX = col_character(),
      EDAD = col_integer(),
      SEXO = col_character(),
      FECHA_RESULTADO = col_date(format = "%Y%m%d")
    ),
    na = c("", "NA", "NULL")
  ) %>%
  mutate(
    SEXO = str_to_title(SEXO)#,
	# errores de fecha detectados 2020-06-23
# 	FECHA_RESULTADO = if_else(
# 	  FECHA_RESULTADO == lubridate::ymd("2020-12-06"),
# 	  lubridate::ymd("2020-06-12"),
# 	  FECHA_RESULTADO
# 	),
# 	FECHA_RESULTADO = if_else(
# 	  FECHA_RESULTADO == lubridate::ymd("2020-11-06"),
# 	  lubridate::ymd("2020-06-11"),
# 	  FECHA_RESULTADO
# 	)
  ) %>%
  mutate_at(
    vars(SEXO, DEPARTAMENTO, PROVINCIA, DISTRITO, METODODX),
    factor
  ) %>%
  janitor::clean_names()

write_csv(
  casos,
  path = "datos/positivos_covid-utf8-limpio.csv"
)

# limpiar archivos extra
file.remove("datos/positivos_covid-utf8.csv")

# fallecimientos ----------------------------------------------------------

fallecimientos <- read_csv(
  "datos/fallecidos_covid-utf8.csv",
  col_types = cols(
    UUID = col_character(),
    FECHA_FALLECIMIENTO = col_date(format = "%Y%m%d"),
    EDAD_DECLARADA = col_number(),
    SEXO = col_character(),
    FECHA_NAC = col_date(format = "%Y%m%d"),
    DEPARTAMENTO = col_character(),
    PROVINCIA = col_character(),
    DISTRITO = col_character()
  )
) %>%
  rename(
    EDAD = EDAD_DECLARADA
  ) %>%
  mutate(
    SEXO = str_to_title(SEXO),
    EDAD_CALC = round(lubridate::interval(FECHA_NAC, FECHA_FALLECIMIENTO) / lubridate::years(), 2)
  ) %>%
  mutate_at(
    vars(SEXO, DEPARTAMENTO, PROVINCIA, DISTRITO),
    factor
  ) %>%
  janitor::clean_names()

write_csv(
  fallecimientos,
  path = "datos/fallecidos_covid-utf8-limpio.csv"
)

# limpiar archivos extra
file.remove("datos/fallecidos_covid-utf8.csv")

# unir datos --------------------------------------------------------------

reconstruido <- casos %>%
  full_join(
    fallecimientos,
    by = c("sexo", "departamento", "provincia", "distrito", "edad")
  ) %>%
  filter(!is.na(uuid.y) &
           fecha_resultado < fecha_fallecimiento &
           fecha_nac < fecha_resultado) %>%
  distinct() %>%
  rename(
    uuid_caso = uuid.x,
    uuid_fallecimiento = uuid.y
  ) %>%
  arrange(uuid_caso)

reconstruido <- reconstruido %>%
  left_join(
    reconstruido %>%
      group_by(uuid_caso) %>%
      tally() %>%
      rename(
        coincidencias = n
      ),
    by = "uuid_caso"
  )

write_csv(
  reconstruido,
  path = "datos/casos_fallecimientos_reconstruccion_posible.csv.gz"
)

save(
  casos, fallecimientos, reconstruido,
  file = "datos/datos_abiertos_minsa_covid-19_peru.Rdata"
)


